//
//  MapMenuViewController.m
//  Knock
//
//  Created by Anna Wang on 11/19/15.
//  Copyright © 2015 Anna Wang. All rights reserved.
//

#import "MapMenuViewController.h"

#define FRIENDS_INDEX 0
#define FOF_INDEX 1
#define STRANGERS_INDEX 2
#define Rgb2UIColor(r, g, b)  [UIColor colorWithRed:((r) / 255.0) green:((g) / 255.0) blue:((b) / 255.0) alpha:1.0]

@interface MapMenuViewController ()

@property (weak, nonatomic) IBOutlet UISwitch *friendsSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *friendsOfFriendsSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *strangersSwitch;
@property (weak, nonatomic) IBOutlet UISlider *distanceSlider;
@property (weak, nonatomic) IBOutlet UILabel *distanceLabel;
@property (weak, nonatomic) IBOutlet UISwitch *discoverableSwitch;
@property (nonatomic, assign) NSUInteger distance;
@property (nonatomic, assign) BOOL friends;
@property (nonatomic, assign) BOOL strangers;
@property (nonatomic, assign) BOOL fOF;
@property (weak, nonatomic) IBOutlet UILabel *nameLabel;

@end

@implementation MapMenuViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.distance = 2;
    self.distanceSlider.minimumValue = 0;
    self.distanceSlider.maximumValue = 12;
    self.friends = YES;
    self.fOF = YES;
    self.strangers = NO;
    
    self.nameLabel.textColor = Rgb2UIColor(46, 187, 145);
    
    if (!UIAccessibilityIsReduceTransparencyEnabled()) {
        self.view.backgroundColor = [UIColor clearColor];
        
        UIBlurEffect *blurEffect = [UIBlurEffect effectWithStyle:UIBlurEffectStyleLight];
        UIVisualEffectView *blurEffectView = [[UIVisualEffectView alloc] initWithEffect:blurEffect];
        blurEffectView.frame = self.view.bounds;
        blurEffectView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
        
        [self.view insertSubview:blurEffectView atIndex:1];
    }
    else {
        self.view.backgroundColor = [UIColor blackColor];
    }

  }

- (IBAction)tapName:(id)sender {
    [self.delegate tappedName];
}

- (void)viewWillAppear:(BOOL)animated
{
    [self.friendsSwitch setOn:self.friends];
    [self.friendsOfFriendsSwitch setOn:self.fOF];
    [self.strangersSwitch setOn:self.strangers];
    [self.distanceSlider setValue:self.distance];

}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)viewWillDisappear:(BOOL)animated
{
    
    //calculate how many friends to show...
    NSInteger distance = roundf(self.distanceSlider.value);
    BOOL friends = self.friendsSwitch.on;
    BOOL fOF = self.friendsOfFriendsSwitch.on;
    BOOL strangers = self.strangersSwitch.on;
    
    self.distance = distance;
    self.friends = friends;
    self.fOF = fOF;
    self.strangers = strangers;
    
    [self.delegate updateMap:distance friends:friends fOF:fOF strangers:strangers];
    
}

- (IBAction)distanceChanged:(id)sender {
    NSString *myString = [[NSNumber numberWithFloat:roundf(self.distanceSlider.value)] stringValue];
    self.distanceLabel.text = [NSString stringWithFormat:@"%@ %@", myString, @"mi"];
}

- (void)updateFilters:(NSInteger)distance friends:(BOOL)friends fOF:(BOOL)fOF strangers:(BOOL)strangers
{
    [self.distanceSlider setValue:distance];
    [self.friendsSwitch setOn:friends];
    [self.friendsOfFriendsSwitch setOn:fOF];
    [self.strangersSwitch setOn:strangers];
    NSString *myString = [[NSNumber numberWithFloat:roundf(self.distanceSlider.value)] stringValue];
    self.distanceLabel.text = [NSString stringWithFormat:@"%@ %@", myString, @"mi"];
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
